@@ -52,6 +52,7 @@ struct Impl_Process {
     iPipe pin;
     iPipe pout;
     iPipe perr;
+    int exitStatus;
 };
 
 iDefineObjectConstruction(Process)
@@ -67,6 +68,7 @@ void init_Process(iProcess *d) {
     init_Pipe(&d->pin);
     init_Pipe(&d->pout);
     init_Pipe(&d->perr);
+    d->exitStatus = 0;
 }
 
 void deinit_Process(iProcess *d) {
@@ -102,6 +104,10 @@ void setWorkingDirectory_Process(iProcess *d, const iString *cwd) {
 }
 
 iBool start_Process(iProcess *d) {
+#if defined (iPlatformAndroid)
+    /* posix_spawn requires API level 28 */
+    return iFalse;
+#else
     posix_spawn_file_actions_t facts;
     int rc;
     const char **argv;
@@ -147,6 +153,7 @@ iBool start_Process(iProcess *d) {
     close(input_Pipe(&d->pout));
     close(input_Pipe(&d->perr));
     return rc == 0;
+#endif
 }
 
 iProcessId pid_Process(const iProcess *d) {
@@ -165,9 +172,17 @@ iBool isRunning_Process(const iProcess *d) {
     return iTrue;
 }
 
+int exitStatus_Process(const iProcess *d) {
+    return d->exitStatus;
+}
+
 void waitForFinished_Process(iProcess *d) {
     if (!d->pid) return;
-    waitpid(d->pid, NULL, 0);
+    int ws = 0;
+    waitpid(d->pid, &ws, 0);
+    if (WIFEXITED(ws)) {
+        d->exitStatus = WEXITSTATUS(ws);
+    }
     d->pid = 0;
 }
 
