@@ -69,6 +69,7 @@ enum iPrefsBool {
     bottomNavBar_PrefsBool,
     bottomTabBar_PrefsBool,
     menuBar_PrefsBool,
+    simpleChars_PrefsBool,
     
     /* Document presentation */
     sideIcon_PrefsBool,
@@ -87,6 +88,8 @@ enum iPrefsBool {
     warnAboutMissingGlyphs_PrefsBool,
     markdownAsSource_PrefsBool,
     
+    skipIndexPageOnParentNavigation_PrefsBool,
+    
     /* Network */
     decodeUserVisibleURLs_PrefsBool,
     
@@ -130,6 +133,7 @@ struct Impl_Prefs {
             iBool bottomNavBar;
             iBool bottomTabBar;
             iBool menuBar;
+            iBool simpleChars;
             
             /* Document presentation */
             iBool sideIcon;
@@ -148,6 +152,8 @@ struct Impl_Prefs {
             iBool warnAboutMissingGlyphs;
             iBool markdownAsSource;
             
+            iBool skipIndexPageOnParentNavigation;
+            
             /* Network */
             iBool decodeUserVisibleURLs;
             
