@@ -2091,9 +2091,11 @@ void setFocus_Widget(iWidget *d) {
             iAssert(!contains_PtrSet(win->focus->root->pendingDestruction, win->focus));
             postCommand_Widget(win->focus, "focus.lost");
         }
+        if (~flags_Widget(d) & focusable_WidgetFlag) {
+            d = NULL; /* focusing this is not allowed */
+        }
         win->focus = d;
         if (d) {
-            iAssert(flags_Widget(d) & focusable_WidgetFlag);
             setKeyRoot_Window(get_Window(), d->root);
             postCommand_Widget(d, "focus.gained");
         }
@@ -2108,7 +2110,8 @@ void setKeyboardGrab_Widget(iWidget *d) {
 }
 
 iWidget *focus_Widget(void) {
-    return get_Window()->focus;
+    iWindow *win = get_Window();
+    return win ? win->focus : NULL;
 }
 
 void setHover_Widget(iWidget *d) {
@@ -2163,21 +2166,27 @@ static const iWidget *findFocusRoot_Widget_(const iWidget *d) {
     return NULL;
 }
 
+const iWidget *focusRoot_Widget(const iWidget *d) {
+    iRoot *uiRoot = (d ? d->root : get_Window()->keyRoot);
+    return findFocusRoot_Widget_(uiRoot->widget);
+}
+
 iAny *findFocusable_Widget(const iWidget *startFrom, enum iWidgetFocusDir focusDir) {
     if (!get_Window()) {
         return NULL;
     }
-    iRoot *uiRoot = (startFrom ? startFrom->root : get_Window()->keyRoot);
-    const iWidget *focusRoot = findFocusRoot_Widget_(uiRoot->widget);
+    const iWidget *focusRoot = focusRoot_Widget(startFrom);
     iAssert(focusRoot != NULL);
     iBool getNext = (startFrom ? iFalse : iTrue);
     const iWidget *found = findFocusable_Widget_(focusRoot, startFrom, &getNext, focusDir);
     if (!found && startFrom) {
         getNext = iTrue;
         /* Switch to the next root, if available. */
-        found = findFocusable_Widget_(findFocusRoot_Widget_(otherRoot_Window(get_Window(),
-                                                                             uiRoot)->widget),
-                                      NULL, &getNext, focusDir);
+        found = findFocusable_Widget_(
+            findFocusRoot_Widget_(otherRoot_Window(get_Window(), focusRoot->root)->widget),
+            NULL,
+            &getNext,
+            focusDir);
     }
     return iConstCast(iWidget *, found);
 }
